@@ -35,7 +35,7 @@ static HBA_STATUS addPortByName(struct vlib_adapter *adapter, char *name)
 	char path[PATH_MAX];
 	char attr[ATTR_MAX];
 	int ret;
-	struct vlib_port port;
+	struct vlib_port port = { .did = 0 };
 
 	snprintf(path, PATH_MAX, "/sys/class/fc_remote_ports/%s", name);
 
@@ -69,7 +69,14 @@ static HBA_STATUS addPortByName(struct vlib_adapter *adapter, char *name)
 static HBA_STATUS addAdapterByDevPath(char *dev_path)
 {
 	char *fc_host_name;
-	struct vlib_adapter a;
+	struct vlib_adapter a = {
+		.ident = {
+			.devid = 0,
+			.wwpn = 0,
+			.wwnn = 0,
+			.did = 0,
+		}
+	};
 	char attr[ATTR_MAX];
 	char classpath[PATH_MAX];
 	int ret;
@@ -81,7 +88,10 @@ static HBA_STATUS addAdapterByDevPath(char *dev_path)
 
 	ret = sfhelper_getProperty(dev_path, "online", attr);
 	if (!ret && strncmp(attr, "0", 1) == 0)
+	{
+		sfhelper_closedir(dir);
 		return HBA_STATUS_ERROR_INVALID_HANDLE;
+	}
 
 	while (fc_host_name = sfhelper_getNextDirEnt(dir)) {
 		if (strncmp(fc_host_name, "host", 4) == 0)
@@ -89,8 +99,11 @@ static HBA_STATUS addAdapterByDevPath(char *dev_path)
 	}
 
 	if (fc_host_name == NULL)
+	{
+		sfhelper_closedir(dir);
 		/* adapter is offline, no fc_host entry */
 		return HBA_STATUS_ERROR_UNAVAILABLE;
+	}
 
 	a.ident.host = strtoul(fc_host_name + 4, NULL, 0);
 	sfhelper_closedir(dir);
@@ -167,7 +180,7 @@ static HBA_STATUS getPortAttributes(HBA_PORTATTRIBUTES **pPortattributes,
 
 	/* Port State */
 	ret = sfhelper_getProperty(classpath, "port_state", attr);
-	if (attr)
+	if (!ret)
 		(*pPortattributes)->PortState =  vlibCharToIntPortState(attr);
 
 	/* Supported Classes */
@@ -333,9 +346,11 @@ int sysfs_getUnitsFromPort(struct vlib_port *port)
 		if (strncmp(dirent, "target", 6) == 0)
 			break;
 	}
-	if (dirent == NULL)
+	if (dirent == NULL) {
+		sfhelper_closedir(dir);
 		/* no units, no error*/
 		return 0;
+	}
 
 	sfhelper_closedir(dir);
 
@@ -493,7 +508,7 @@ HBA_STATUS sysfs_getAdapterAttributes(HBA_ADAPTERATTRIBUTES **pAttrs,
 						struct vlib_adapter *adapter)
 {
 	char classpath[PATH_MAX], attr[ATTR_MAX];
-	int ret, a;
+	int ret, a, str_size = 0;
 
 	memset(*pAttrs, 0, sizeof(HBA_ADAPTERATTRIBUTES));
 
@@ -505,7 +520,11 @@ HBA_STATUS sysfs_getAdapterAttributes(HBA_ADAPTERATTRIBUTES **pAttrs,
 	/* Serial Number */
 	ret = sfhelper_getProperty(classpath, "serial_number", attr);
 	if (!ret)
-		strcpy((*pAttrs)->SerialNumber, attr);
+	{
+		str_size = min(sizeof((*pAttrs)->SerialNumber), strlen(attr));
+		strncpy((*pAttrs)->SerialNumber, attr, str_size);
+		(*pAttrs)->SerialNumber[str_size] = '\0';
+	}
 
 	/* Model */
 	ret = sfhelper_getProperty(adapter->ident.sysfsPath, "card_version",
